Class: Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent
- Inherits:
-
Object
- Object
- Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/datastore/admin/v1/migration.rb
Overview
An event signifying the start of a new step in a migration from Cloud Datastore to Cloud Firestore in Datastore mode.
Defined Under Namespace
Modules: ConcurrencyMode Classes: PrepareStepDetails, RedirectWritesStepDetails
Instance Attribute Summary collapse
-
#prepare_step_details ⇒ ::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::PrepareStepDetails
Details for the
PREPAREstep. -
#redirect_writes_step_details ⇒ ::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::RedirectWritesStepDetails
Details for the
REDIRECT_WRITESstep. -
#step ⇒ ::Google::Cloud::Datastore::Admin::V1::MigrationStep
The step that is starting.
Instance Attribute Details
#prepare_step_details ⇒ ::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::PrepareStepDetails
Returns Details for the PREPARE step.
Note: The following fields are mutually exclusive: prepare_step_details, redirect_writes_step_details. If a field in that set is populated, all other fields in the set will automatically be cleared.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/datastore/admin/v1/migration.rb', line 55 class MigrationProgressEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details for the `PREPARE` step. # @!attribute [rw] concurrency_mode # @return [::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::ConcurrencyMode] # The concurrency mode this database will use when it reaches the # `REDIRECT_WRITES` step. class PrepareStepDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Details for the `REDIRECT_WRITES` step. # @!attribute [rw] concurrency_mode # @return [::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::ConcurrencyMode] # Ths concurrency mode for this database. class RedirectWritesStepDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Concurrency modes for transactions in Cloud Firestore. module ConcurrencyMode # Unspecified. CONCURRENCY_MODE_UNSPECIFIED = 0 # Pessimistic concurrency. PESSIMISTIC = 1 # Optimistic concurrency. OPTIMISTIC = 2 # Optimistic concurrency with entity groups. OPTIMISTIC_WITH_ENTITY_GROUPS = 3 end end |
#redirect_writes_step_details ⇒ ::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::RedirectWritesStepDetails
Returns Details for the REDIRECT_WRITES step.
Note: The following fields are mutually exclusive: redirect_writes_step_details, prepare_step_details. If a field in that set is populated, all other fields in the set will automatically be cleared.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/datastore/admin/v1/migration.rb', line 55 class MigrationProgressEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details for the `PREPARE` step. # @!attribute [rw] concurrency_mode # @return [::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::ConcurrencyMode] # The concurrency mode this database will use when it reaches the # `REDIRECT_WRITES` step. class PrepareStepDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Details for the `REDIRECT_WRITES` step. # @!attribute [rw] concurrency_mode # @return [::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::ConcurrencyMode] # Ths concurrency mode for this database. class RedirectWritesStepDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Concurrency modes for transactions in Cloud Firestore. module ConcurrencyMode # Unspecified. CONCURRENCY_MODE_UNSPECIFIED = 0 # Pessimistic concurrency. PESSIMISTIC = 1 # Optimistic concurrency. OPTIMISTIC = 2 # Optimistic concurrency with entity groups. OPTIMISTIC_WITH_ENTITY_GROUPS = 3 end end |
#step ⇒ ::Google::Cloud::Datastore::Admin::V1::MigrationStep
Returns The step that is starting.
An event with step set to START indicates that the migration
has been reverted back to the initial pre-migration state.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'proto_docs/google/datastore/admin/v1/migration.rb', line 55 class MigrationProgressEvent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Details for the `PREPARE` step. # @!attribute [rw] concurrency_mode # @return [::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::ConcurrencyMode] # The concurrency mode this database will use when it reaches the # `REDIRECT_WRITES` step. class PrepareStepDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Details for the `REDIRECT_WRITES` step. # @!attribute [rw] concurrency_mode # @return [::Google::Cloud::Datastore::Admin::V1::MigrationProgressEvent::ConcurrencyMode] # Ths concurrency mode for this database. class RedirectWritesStepDetails include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Concurrency modes for transactions in Cloud Firestore. module ConcurrencyMode # Unspecified. CONCURRENCY_MODE_UNSPECIFIED = 0 # Pessimistic concurrency. PESSIMISTIC = 1 # Optimistic concurrency. OPTIMISTIC = 2 # Optimistic concurrency with entity groups. OPTIMISTIC_WITH_ENTITY_GROUPS = 3 end end |