Module: Google::Cloud::Datastore::Admin::V1::MigrationStep
- Defined in:
- proto_docs/google/datastore/admin/v1/migration.rb
Overview
Steps in a migration.
Constant Summary collapse
- MIGRATION_STEP_UNSPECIFIED =
Unspecified.
0- PREPARE =
Pre-migration: the database is prepared for migration.
6- START =
Start of migration.
1- APPLY_WRITES_SYNCHRONOUSLY =
Writes are applied synchronously to at least one replica.
7- COPY_AND_VERIFY =
Data is copied to Cloud Firestore and then verified to match the data in Cloud Datastore.
2- REDIRECT_EVENTUALLY_CONSISTENT_READS =
Eventually-consistent reads are redirected to Cloud Firestore.
3- REDIRECT_STRONGLY_CONSISTENT_READS =
Strongly-consistent reads are redirected to Cloud Firestore.
4- REDIRECT_WRITES =
Writes are redirected to Cloud Firestore.
5